@@ -1,8 +1,6 @@
 from dataclasses import asdict
-
-from django.http import JsonResponse
-
-from common.rest_extend.response import Results, get_error_status_code, RESTResponse
+from tenant_auth.models import Tenant
+from common.rest_extend.response import Results, get_error_status_code, RESTResponse, FORBID_CODE
 
 
 def vaild_decorator(obj=None, obj_serializer=None, partial=False):
@@ -61,8 +59,8 @@ def view_decorator(function):
     return wrapper
 
 
-def relevance_vaild_legal_decorator(func):
-    def wrapper(request, *args, **kwargs):
+def related_vaild_legal_decorator(func):
+    def wrapper(obj, request, *args, **kwargs):
         # if request.method != "GET" and request.method != "POST":
         #     return JsonResponse({"detail": f'Method "{request.method}" not allowed.'}, status=405)
         group = request.GET.get("group")
@@ -70,15 +68,44 @@ def relevance_vaild_legal_decorator(func):
             results = Results()
             results.describe = "此接口不支持参数 'group'！！！"
             return RESTResponse(results)
-        return func(request, *args, **kwargs)
+        return func(obj, request, *args, **kwargs)
 
     return wrapper
 
 
 def tenant_decorator(func):
-    def wrapper(request, *args, **kwargs):
-        account = request.session.get('account')
+    def wrapper(obj_view, request, *args, **kwargs):
+        tenant = None
+        req_args = dict(request.GET.dict())
+        token = req_args.pop('token', None)
+        if request.method == 'GET':
+            data = req_args
+        else:
+            data = request.data
 
-        return func(request, *args, **kwargs)
+        if token:
+            tenant = Tenant.objects.filter(token=token).first()
+        else:
+            account = request.session.get('account')
+            if account:
+                tenant = Tenant.objects.filter(account=account).first()
+        if tenant:
+            if 'data' in data.keys() and 'ops' in data.keys():
+                data = data.get('data', {})
+            if request.method == 'POST':
+                data['creator'] = tenant.name
+                kwargs["data"] = data
+            ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
+            if not ignore_creator:
+                if "extend_conditions" in kwargs.keys():
+                    kwargs["extend_conditions"]['creator'] = data
+                else:
+                    kwargs["extend_conditions"] = {"creator": tenant.name}
+            return func(obj_view, request, *args, **kwargs)
+        else:
+            results = Results()
+            results.code = FORBID_CODE
+            results.describe = "无登陆信息!!!"
+            return RESTResponse(results)
 
     return wrapper
