@@ -6,8 +6,6 @@ from django.core.serializers.json import DjangoJSONEncoder
 from django.http import JsonResponse
 from rest_framework.exceptions import ValidationError
 
-
-
 SUCCESS = "success"
 FAILURE = "failure"
 
@@ -17,7 +15,6 @@ FAILURE = "failure"
 # 请求错误码（主要是参数校验）
 REQUEST_ERROR_CODE = 400
 
-
 # 未授权
 UNAUTHORIZED = 401
 
@@ -48,25 +45,6 @@ def init_version(version: str):
     results_version = version
 
 
-def get_error_status_code(error):
-    """
-    根据错误类型，获取状态码和信息
-    :param error:
-    :return:
-    """
-    logger.exception(error)
-    if isinstance(error, ValidationError):
-        status_code = REQUEST_ERROR_CODE
-    elif isinstance(error, ValueError):
-        status_code = REQUEST_ERROR_CODE
-    elif isinstance(error, FieldError):
-        status_code = REQUEST_ERROR_CODE
-    else:
-        status_code = SERVER_ERROR_CODE
-    describe = str(error)
-    return status_code, describe
-
-
 @dataclass
 class Results:
     status: str = FAILURE
@@ -129,3 +107,25 @@ class RESTResponse(JsonResponse):
             super(RESTResponse, self).__init__(
                 data, encoder=encoder, safe=safe, json_dumps_params=json_dumps_params, **kwargs
             )
+
+
+def get_error_status_code(error, results: Results = None):
+    """
+    根据错误类型，获取状态码和信息
+    :param error:
+    :return:
+    """
+    logger.exception(error)
+    if isinstance(error, ValidationError):
+        status_code = REQUEST_ERROR_CODE
+    elif isinstance(error, ValueError):
+        status_code = REQUEST_ERROR_CODE
+    elif isinstance(error, FieldError):
+        status_code = REQUEST_ERROR_CODE
+    else:
+        status_code = SERVER_ERROR_CODE
+    describe = str(error)
+    if isinstance(results, Results):
+        results.code = status_code
+        results.describe = describe
+    return status_code, describe
