@@ -70,7 +70,13 @@ class ESClient(BaseArgsParsing):
                             if itme[1] in range_item[key].keys():
                                 range_item[key][itme[1]] = self.build(range_item[key], ".".join(itme[1:]), field, vaule)
                                 return body
-                body.append({key: self.build({}, ".".join(itme[1:]), field, vaule)})
+                else:
+                    for item in body:
+                        if key in item.keys():
+                            item[key] = self.build(item[key], ".".join(itme[1:]), field, vaule)
+                            break
+                    else:
+                        body.append({key: self.build({}, ".".join(itme[1:]), field, vaule)})
                 return body
 
         else:
@@ -147,8 +153,12 @@ class ESClient(BaseArgsParsing):
         body = self.build(body, "query.bool.must_not.match_phrase", key, value)
         return body
 
-    def must_and_should(self, key, value, body=None):
-        body = self.build(body, "query.bool.must.bool.should.match_phrase", key, value)
+    def must_and_should(self, key, *, values: list = None, body=None):
+        if not values:
+            raise ValueError("'values' is none!!!")
+        for value in values:
+            if value:
+                body = self.build(body, "query.bool.must.bool.should.match_phrase", key, value)
         return body
 
     def search(self, body, index, page=1, size=20):
@@ -196,6 +206,6 @@ if __name__ == "__main__":
         host="config.esmeas.host",
         port="config.esmeas.port",
         username="config.esmeas.username",
-        password="config.esmeas.password"
+        password="config.esmeas.password",
     )
     es.index()
